#ifndef SRMRENDERMODECPU_H
#define SRMRENDERMODECPU_H

#include <SRMTypes.h>

#ifdef __cplusplus
extern "C" {
#endif

void srmRenderModeCPUSetInterface(SRMConnector *connector);

#ifdef __cplusplus
}
#endif

#endif // SRMRENDERMODECPU_H
